setup
=====

This chapter will give you an introduction on how to install and get started with this module.

.. toctree::
   :maxdepth: 2

   Installation <Install.md>
   Configuration <Configuration.md>
   Quick-start <Quickstart.md>
   Hosting <Hosting.md>